#
# spec file for package python-girder-client
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-girder-client
Version:        3.2.1
Release:        1.7
Summary:        Python Girder client
License:        Apache-2.0
URL:            https://girder.readthedocs.io/en/latest/python-client.html
Source:         https://files.pythonhosted.org/packages/source/g/girder-client/girder-client-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click >= 6.7
Requires:       python-diskcache
Requires:       python-requests >= 2.4.2
Requires:       python-requests-toolbelt
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Girder is a web-based data management platform.

This package provides the client for interacting
with Girder servers

%prep
%setup -q -n girder-client-%{version}
sed -i -e '/^#!\//, 1d' girder_client/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/girder-client
%python_clone -a %{buildroot}%{_bindir}/girder-cli
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative girder-client
%python_install_alternative girder-cli

%postun
%python_uninstall_alternative girder-client
%python_uninstall_alternative girder-cli

%files %{python_files}
%doc README.rst
%python_alternative %{_bindir}/girder-cli
%python_alternative %{_bindir}/girder-client
%{python_sitelib}/*

%changelog
* Sat Feb  3 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * metadata fixes
  * python 3.8 required
- switch to PEP517 build
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.24:
  * Update swagger-ui from version 2.x to 5.x.
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.20:
  * long list of fixes, see https://github.com/girder/girder/compare/v3.1.3...v3.1.20
* Thu Nov 12 2020 Marketa Machova <mmachova@suse.com>
- update to 3.1.3
  * few fixes and improvements, see commits on GitHub
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.0.8
  * Add lockfiles for ancillary npm packages
- Update to 3.0.7
  * Add filter for local plugins
  * Fix code style and improve build efficiency
  * Fix incorrect list.extend usage
  * Fix invalid python2 syntax
  * Update girder build to remove old node_modules
  * Rename the Ansible variable girder_package_path and default it to empty
  * Clarify girder_version Ansible parameter docs
  * In Ansible, remove "girder_pip_extra_args" and make "girder_version"
  * Update molecule dependencies
  * Ensure core swagger client does not put passwords in URL
  * Fix an issue with publishing npm packages
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.0.6
  * Added a --token option to the girder-client command line
    interface to allow users to specify a pre-created authentication
    token.
  * Added a --retry option to the girder-client command line
    interface to retry connection and certain error responses.
  * Added a --verbose option to the girder-client command line
    interface to increase the verbosity of information dumped to
    stderr.
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 3.0.5
  * Update Google OAuth provider to use new OpenID Connect API
- Update to 3.0.4
  * Remove python-dateutil requirement.
- Update to 3.0.3
  * Add indices to audit logs
- Update to 3.0.2
  * Harden the logic when a passwordless user needs to login with OAuth
- Update to 3.0.1
  * Remove some hardcoded version numbers
- Update to 3.0.0
  * Explicitly forbid multipart upload
  * Remove the access.cookie decorator.
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
